 /*
 * file      : src/win_export.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */



#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>
#include <cairo.h>
#include <cairo-pdf.h>
#include <cairo-ps.h>
#include <cairo-xlib.h>
#include <X11/Xlib.h>
#include <string.h>
#include <stdlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "configuser.h"
#include "fileselect.h"
#include "win_export.h"



typedef struct {

	GtkWidget	*AdrWin;			// Adresse de la fenetre
	gboolean	IsShow;				// TRUE or FALSE
	GtkWidget	*AdrButtonExportPathnamefile;	// Adresse button export
	GtkWidget	*AdrCheckbuttonPDF;		// 
	GtkWidget	*AdrCheckbuttonPNG;		// 
	GtkWidget	*AdrCheckbuttonPS;		// 
	GtkWidget	*AdrCheckbuttonTXT;		// 
	void		(*FuncExtern)( void );		// 
	
	gboolean	BoolEnterCheckbuttonMonth;		// 
	gboolean	BoolEnterCheckbuttonPrint;		// 
	
} VAR_WIN_EXPORT;

VAR_WIN_EXPORT VarWinExport = { 
	
	NULL,
	FALSE,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	TRUE,
	TRUE
	
	};





// 
// 
void WinExport_set_sensitive_button_apply( void )
{
	gboolean	CheckExportPrint = Config.CheckExportPrint > 0 ? TRUE : FALSE;
	gboolean	CheckbuttonMonth = Config.CheckbuttonMonth > 0 ? TRUE : FALSE;
	
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_print_ok")), CheckExportPrint & CheckbuttonMonth );
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_print_apply")), CheckExportPrint & CheckbuttonMonth );
}
// EVENT: DESTROY, DELETE
// 
gboolean on_window_export_destroy_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	return( TRUE );
}
gboolean on_window_export_delete_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	return( TRUE );
}

// BUTTON: OK CANCEL
// 
void on_button_print_cancel_clicked( GtkButton *button, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
}
void on_button_print_apply_clicked( GtkButton *button, gpointer user_data )
{
	// L'AFFICHAGE EST FAIT DEPUIS L'EXTERIEUR
	if( VarWinExport.FuncExtern ) (*VarWinExport.FuncExtern)();
}
void on_button_print_ok_clicked( GtkButton *button, gpointer user_data )
{
	VarWinExport.IsShow = FALSE;
	gtk_widget_hide( VarWinExport.AdrWin );
	// L'AFFICHAGE EST FAIT DEPUIS L'EXTERIEUR
	if( VarWinExport.FuncExtern ) (*VarWinExport.FuncExtern)();
}

// BUTTON: PATHNAME
// 
void on_button_pathname_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.AdrButtonExportPathnamefile = widget;
	
	if( FALSE == libutils_test_dir_exist( Config.PathNameFileExport )) {
		g_free( Config.PathNameFileExport );
		Config.PathNameFileExport = NULL;
		Config.PathNameFileExport = g_strdup( getenv ("HOME") );
	}
	gtk_button_set_label( GTK_BUTTON(VarWinExport.AdrButtonExportPathnamefile), Config.PathNameFileExport );
}
void WinExport_select( gchar *p_path )
{
	// TESTS SUR:
	// pdf
	// png
	// ps
	// txt
	
	g_print( "p_path = %s\n", p_path );

	g_free( Config.PathNameFileExport );
	Config.PathNameFileExport = NULL;
	Config.PathNameFileExport = g_strdup( p_path );
	gtk_button_set_label( GTK_BUTTON(VarWinExport.AdrButtonExportPathnamefile), Config.PathNameFileExport );

}
void on_button_pathname_clicked( GtkButton *button, gpointer user_data )
{
	fileselect( _("Choix d'un nom de fichier pour l'exportation"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,  WinExport_select, Config.PathNameFileExport, VarWinExport.AdrWin );
}

// EXPORT FORMATS: PDF PNG PS TXT
// 
void on_checkbutton_print_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.BoolEnterCheckbuttonPrint = FALSE;
	
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_pdf")))
		if( Config.CheckExportPrint & CHECKBUTTON_PDF )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_png")))
		if( Config.CheckExportPrint & CHECKBUTTON_PNG )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_ps")))
		if( Config.CheckExportPrint & CHECKBUTTON_PS )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_txt")))
		if( Config.CheckExportPrint & CHECKBUTTON_TXT )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	WinExport_set_sensitive_button_apply();
	
	VarWinExport.BoolEnterCheckbuttonPrint = TRUE;
}
void on_checkbutton_print_clicked( GtkButton *button, gpointer user_data )
{
	if( FALSE == VarWinExport.BoolEnterCheckbuttonPrint ) return;
	
	Config.CheckExportPrint = 0;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_pdf")))) )
		Config.CheckExportPrint |= CHECKBUTTON_PDF;
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_png")))) )
		Config.CheckExportPrint |= CHECKBUTTON_PNG;
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_ps")))) )
		Config.CheckExportPrint |= CHECKBUTTON_PS;
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_print_txt")))) )
		Config.CheckExportPrint |= CHECKBUTTON_TXT;
	
	WinExport_set_sensitive_button_apply();
}

// EXPORT MOIS: JANVIER .. DECEMBRE
// 
void on_checkbutton_month_realize( GtkWidget *widget, gpointer user_data )
{
	VarWinExport.BoolEnterCheckbuttonMonth = FALSE;
	
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_janvier")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_JANVIER )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_fevrier")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_FEVRIER )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_mars")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_MARS )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_avril")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_AVRIL )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_mai")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_MAI )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_juin")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_JUIN )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_juillet")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_JUILLET )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_aout")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_AOUT )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_septembre")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_SEPTEMBRE )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_octobre")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_OCTOBRE )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_novembre")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_NOVEMBRE )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	if( widget == GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_decembre")))
		if( Config.CheckbuttonMonth & CHECKBUTTON_DECEMBRE )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), TRUE );
	
	WinExport_set_sensitive_button_apply();
	
	VarWinExport.BoolEnterCheckbuttonMonth = TRUE;
}
void on_checkbutton_month_clicked( GtkButton *button, gpointer user_data )
{
	if( FALSE == VarWinExport.BoolEnterCheckbuttonMonth ) return;
	
	Config.CheckbuttonMonth = 0;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_janvier")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_JANVIER;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_fevrier")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_FEVRIER;

	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_mars")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_MARS;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_avril")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_AVRIL;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_mai")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_MAI;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_juin")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_JUIN;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_juillet")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_JUILLET;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_aout")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_AOUT;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_septembre")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_SEPTEMBRE;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_octobre")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_OCTOBRE;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_novembre")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_NOVEMBRE;
	
	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_decembre")))) )
		Config.CheckbuttonMonth |= CHECKBUTTON_DECEMBRE;
	
	WinExport_set_sensitive_button_apply();
}

// OPEN WINDOW
// 
void WinExport_open( void (*FuncExtern) ( void ) )
{
	VarWinExport.FuncExtern = FuncExtern;
	
	if( TRUE == VarWinExport.IsShow ) {
		gdk_window_raise( VarWinExport.AdrWin->window );
	}
	else {
		if( NULL == VarWinExport.AdrWin ) {
			VarWinExport.AdrWin = GTK_WIDGET(GLADE_GET_OBJECT("window_export"));
			gtk_builder_connect_signals( GtkBuilderProjet, NULL );
		}
		gtk_window_set_transient_for( GTK_WINDOW(VarWinExport.AdrWin), GTK_WINDOW(WindMain) );
		gtk_window_set_modal( GTK_WINDOW(VarWinExport.AdrWin), TRUE );
		libutils_set_default_icone_to_win( VarWinExport.AdrWin );
		gtk_window_set_title( GTK_WINDOW( VarWinExport.AdrWin ), "Time Management" );
		gtk_window_set_position( GTK_WINDOW(VarWinExport.AdrWin), GTK_WIN_POS_CENTER );
		VarWinExport.IsShow = TRUE;
		gtk_widget_show( VarWinExport.AdrWin );
	}
}

















